/* check for protocol.ini against ibmlan.ini */
/*
Trace 'N'
*/

Parse Source . . our_cmd .
our_path = Filespec('d', our_cmd)||Filespec('p', our_cmd)
If Length(our_path) > 3 Then
   our_dir = Strip(our_path, 't', '\')
Else
   our_dir = our_path
save_dir = Directory(our_dir)
/* Load RexxUtil.DLL */
Call Rxfuncadd 'SysLoadFuncs','Rexxutil','SysLoadFuncs'
Call SysLoadFuncs
/* Load RexxIni.DLL */
Call Rxfuncadd 'IniLoadFuncs','RexxIni','IniLoadFuncs'
Call IniLoadFuncs
Parse Arg log_name .
retcode = Check_protocol(log_name)
Call Directory save_dir
Return retcode

Check_protocol: Procedure
Parse Arg log_name, .
/* now see if protocol.ini is present */
protocol = SysSearchPath('dpath', 'protocol.ini')
If protocol = '' Then
   Do
      Call Lineout log_name, 'PROTOCOL.INI was not found in your current data path'
      '@pause'
      Return 1
   End

/* now see if ibmlan.ini is present */
ibmlan = SysSearchPath('dpath', 'ibmlan.ini')
If ibmlan = '' Then
   Do
      Call Lineout log_name, 'IBMLAN.INI was not found in your current data path'
      '@pause'
      Return 1
   End

/* do we have netbeui or tcpbeui */
netbios_driver = IniGet('drivername', 'netbios', protocol)

/* now get the netbios information */
If netbios_driver <> '' Then
   Do
      frc = IniEnum('netbios.', 'netbios', protocol)
      If frc > 0 Then
         Do
            adapter. = ''
            sessions. = ''
            ncbs. = ''
            names. = ''
            y = 0
            Do x = 1 To netbios.0
               If Abbrev(Translate(netbios.x), 'ADAPTER') Then
                  Do
                     y = y + 1
                     adapter.y = netbios.x '=' IniGet(netbios.x, 'netbios', protocol)
                     Parse Var adapter.y . '=' nif_name '$' .
                     nif_name = Strip(nif_name) || '_nif'
                     sessions.y = IniGet('sessions', nif_name, protocol)
                     ncbs.y = IniGet('ncbs', nif_name, protocol)
                     names.y = IniGet('names', nif_name, protocol)
                     adapter.0 = y
                  End
            End
         End

      /* now get the networks information */
      frc = IniEnum('nets.', 'networks', ibmlan)
      If frc > 0 Then
         Do
            net. = ''
            y = 0
            Do x = 1 To nets.0
               If Abbrev(Translate(nets.x), 'NET') Then
                  Do
                     y = y + 1
                     net.y = nets.x '=' IniGet(nets.x, 'networks', ibmlan)
                     net.0 = y
                  End
            End
         End

      /* get the requester and peer entries in ibmlan.ini */
      c_wrknets = IniGet('wrknets', 'requester', ibmlan)
      c_srvnets = IniGet('srvnets', 'peer', ibmlan)

      /* build an updated networks section */
      tcpbeui = 0
      new_net. = ''
      y = 0
      net_info = ''
      Do x = 1 To adapter.0
         Parse Var adapter.x . '=' net_driver ',' net_number .
         net_name = 'net' || x
         net_driver = Translate(Strip(net_driver))
         If Abbrev(net_driver, 'TCP') Then
            tcpbeui = tcpbeui + 1
         net_number = Strip(net_number)
         /* get parameter values for this network from ibmlan.ini */
         c_net = IniGet(net_name, 'networks', ibmlan)
         If c_net <> '' Then
            Parse Var c_net . ',' . ',' . ',' c_sessions ',' c_ncbs ',' c_names .
         Else
            Do
               /* set to defaults */
               c_sessions = 34
               c_ncbs = 70
               c_names = 14
            End
         /* make sure that information does not exceed the values in protocol.ini */
         c_sessions = Min(c_sessions, sessions.x)
         c_ncbs = Min(c_ncbs, ncbs.x)
         c_names = Min(c_names, names.x)
         y = y + 1
         new_net.y = net_name '=' net_driver || ',' || net_number || ,
            ',LM10,' || c_sessions || ',' || c_ncbs || ',' || c_names
         net_info = Strip(net_info || net_name || ',')
         new_net.0 = y
      End
      net_info = Strip(net_info, 't', ',')

      /* check the network section */
      n_update = 0
      If new_net.0 <> nets.0 Then
         n_update = 1
      Else
         Do x = 1 To new_net.0
            Do y = 1 To net.0
               If Translate(Word(new_net.x, 1)) = Translate(Word(net.y, 1)) Then
                  Do
                     If Space(Translate(new_net.x)) <> Space(Translate(net.y)) Then
                        If \n_update Then
                        n_update = 1
                  End
            End
         End

      /* check the requester section */
      r_update = 0
      If c_wrknets <> '' Then
         If \r_update Then
         r_update = (Translate(net_info) <> Translate(c_wrknets))

      /* check the peer section */
      p_update = 0
      If c_srvnets <> '' Then
         If \p_update Then
         p_update = (Translate(net_info) <> Translate(c_srvnets))

      /* do the update if necessary */
      If n_update | r_update | p_update Then
         DO
         Call Lineout log_name, 'Updating' ibmlan
         '@pause'
         end
       Else do
         Call Lineout log_name, 'No updates to' ibmlan 'were necessary'
         '@pause' 
         end  
       If n_update Then
         Do
            /* save the old ibmlan.ini */
            save_ibmlan = SysTempFileName(Filespec('d', ibmlan) || Filespec('p', ibmlan) || 'IBMLAN.???')
            Call Lineout log_name, 'Saving' ibmlan 'as' save_ibmlan
            Address cmd '@copy' ibmlan save_ibmlan '> nul'
            /* delete all of the current networks entries */
            handle = IniOpen('networks', ibmlan)
            Do x = 1 To net.0
               frc = IniDel('net' || x, handle)
            End
            Do x = 1 To new_net.0
               Parse Var new_net.x new_name '=' new_info
               frc = IniSet(new_name, new_info, handle)
            End
            frc = IniSave(handle)
            frc = IniClose(handle)
         End
      If r_update Then
         Do
            handle = IniOpen('requester', ibmlan)
            If handle > 0 Then
               Do
                  frc = IniSet('wrknets', net_info, handle)
                  frc = IniSave(handle)
                  frc = IniClose(handle)
               End
         End
      If p_update Then
         Do
            handle = IniOpen('peer', ibmlan)
            If handle > 0 Then
               Do
                  frc = IniSet('srvnets', net_info, handle)
                  frc = IniSave(handle)
                  frc = IniClose(handle)
               End
         End
   End
   'exit'
Return 0
